/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */

#undef BONOBO_ACTIVATION_DEBUG

#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef GETTEXT_PACKAGE
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY

/*Always define if getaddrinfo() is defined on the system.*/
#undef HAVE_GETADDRINFO
